@@ -1,6 +1,10 @@
 package net.bytebuddy.test.c;
 
-import java.io.*;
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
 
 @SuppressWarnings("restricted")
 public class NativeSample {
